@@ -1,5 +1,5 @@
 package Spreadsheet::Read::Ingester ;
-$Spreadsheet::Read::Ingester::VERSION = '0.002';
+$Spreadsheet::Read::Ingester::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -111,7 +111,8 @@ Returns an object identical to the object returned by the L<Spreadsheet::Read>
 module along with its corresponding methods.
 
 =head2 cleanup($days)
-=method cleanup()
+
+=head2 cleanup()
 
   Spreadsheet::Read::Ingester->cleanup(0);
 
